==> v0.10.0.tar.gz: hub/database/tests/functions/repositories/get_repository_summary.sql <==
-- Start transaction and plan tests
begin;
select plan(3);

-- Declare some variables
\set user1ID '00000000-0000-0000-0000-000000000001'
\set repo1ID '00000000-0000-0000-0000-000000000001'
\set repo2ID '00000000-0000-0000-0000-000000000002'

-- Non existing repository
select is_empty(
    $$ select get_repository_summary('00000000-0000-0000-0000-000000000001') $$,
    'If repository requested does not exist no rows are returned'
);

-- Seed some data
insert into "user" (user_id, alias, email)
values (:'user1ID', 'user1', 'user1@email.com');
insert into repository (
    repository_id,
    name,
    display_name,
    url,
    repository_kind_id,
    user_id
)
values (
    :'repo1ID',
    'repo1',
    'Repo 1',
    'https://repo1.com',
    0,
    :'user1ID'
);
insert into repository (
    repository_id,
    name,
    display_name,
    url,
    auth_user,
    auth_pass,
    repository_kind_id,
    user_id
)
values (
    :'repo2ID',
    'repo2',
    'Repo 2',
    'https://repo2.com',
    'user',
    'pass',
    0,
    :'user1ID'
);

-- One repository has just been seeded
select is(
    get_repository_summary('00000000-0000-0000-0000-000000000001')::jsonb,
    '{
        "repository_id": "00000000-0000-0000-0000-000000000001",
        "name": "repo1",
        "display_name": "Repo 1",
        "url": "https://repo1.com",
        "private": false,
        "kind": 0,
        "verified_publisher": false,
        "official": false,
        "user_alias": "user1",
        "organization_name": null,
        "organization_display_name": null
    }'::jsonb,
    'Repository 1 is returned as a json object'
);
select is(
    get_repository_summary('00000000-0000-0000-0000-000000000002')::jsonb,
    '{
        "repository_id": "00000000-0000-0000-0000-000000000002",
        "name": "repo2",
        "display_name": "Repo 2",
        "url": "https://repo2.com",
        "private": true,
        "kind": 0,
        "verified_publisher": false,
        "official": false,
        "user_alias": "user1",
        "organization_name": null,
        "organization_display_name": null
    }'::jsonb,
    'Repository 2 is returned as a json object'
);

-- Finish tests and rollback transaction
select * from finish();
rollback;

==> v0.11.0.tar.gz: hub/database/tests/functions/repositories/get_repository_summary.sql <==
-- Start transaction and plan tests
begin;
select plan(3);

-- Declare some variables
\set user1ID '00000000-0000-0000-0000-000000000001'
\set repo1ID '00000000-0000-0000-0000-000000000001'
\set repo2ID '00000000-0000-0000-0000-000000000002'

-- Non existing repository
select is_empty(
    $$ select get_repository_summary('00000000-0000-0000-0000-000000000001') $$,
    'If repository requested does not exist no rows are returned'
);

-- Seed some data
insert into "user" (user_id, alias, email)
values (:'user1ID', 'user1', 'user1@email.com');
insert into repository (
    repository_id,
    name,
    display_name,
    url,
    repository_kind_id,
    user_id
)
values (
    :'repo1ID',
    'repo1',
    'Repo 1',
    'https://repo1.com',
    0,
    :'user1ID'
);
insert into repository (
    repository_id,
    name,
    display_name,
    url,
    auth_user,
    auth_pass,
    repository_kind_id,
    user_id
)
values (
    :'repo2ID',
    'repo2',
    'Repo 2',
    'https://repo2.com',
    'user',
    'pass',
    0,
    :'user1ID'
);

-- One repository has just been seeded
select is(
    get_repository_summary('00000000-0000-0000-0000-000000000001')::jsonb,
    '{
        "repository_id": "00000000-0000-0000-0000-000000000001",
        "name": "repo1",
        "display_name": "Repo 1",
        "url": "https://repo1.com",
        "private": false,
        "kind": 0,
        "verified_publisher": false,
        "official": false,
        "user_alias": "user1"
    }'::jsonb,
    'Repository 1 is returned as a json object'
);
select is(
    get_repository_summary('00000000-0000-0000-0000-000000000002')::jsonb,
    '{
        "repository_id": "00000000-0000-0000-0000-000000000002",
        "name": "repo2",
        "display_name": "Repo 2",
        "url": "https://repo2.com",
        "private": true,
        "kind": 0,
        "verified_publisher": false,
        "official": false,
        "user_alias": "user1"
    }'::jsonb,
    'Repository 2 is returned as a json object'
);

-- Finish tests and rollback transaction
select * from finish();
rollback;
